//  Copyright 2009 David Ekholm, Jalbum AB
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.package net.jalbum.editor;

package DiskUsage;

import java.util.*;
import java.io.*;
import javax.swing.*;
//import crushftp.server.*;

/**
 * CrushFTP plugin class
 * @author david
 */
public class Start implements Serializable {

    Properties settings = new Properties();
    String version = "1.0";
    GUI g = null;

    public Properties getDefaults() {
        //log("getDefaults called");
        Properties p = new Properties();
        p.put("enabled", "false");
        p.put("debug", "false");
        p.put("forceCacheRefresh", "false");
        p.put("version", version);
        return p;
    }

    public void setSettings(Properties p) throws Exception {
        //log("setSettings called");

        settings = p;
        if (g != null) {
            g.setSettings(settings);
        }
    }

    public Properties getSettings() {
        //log("getSettings called");

        if (g != null) {
            settings = g.getSettings();
        }
        settings.put("version", version);
        return settings;
    }

    public javax.swing.JPanel getPrefsPanel() {
        //log("getPrefsPanel called");

        if (g == null) {
            g = new GUI();
        }
        g.setParent(this);
        g.setSettings(settings);
        return g;
    }

    public Object run(Properties info) {
        if (!settings.getProperty("enabled").equalsIgnoreCase("true")) {
            return null;
        }

        String action = info.getProperty("action", "");
        if (action.equals("getUsedQuota")) {
            String realPath = info.getProperty("realPath");
            try {
                boolean forceCacheRefresh = settings.getProperty("forceCacheRefresh").equalsIgnoreCase("true");
                long usedQuota = net.jalbum.diskusage.DiskUsage.getDiskUsage(new File(realPath), forceCacheRefresh);
                info.setProperty("usedQuota", "" + usedQuota);
                debug("DiskUsage: Used disk space for path " + realPath + ": " + usedQuota);
            } catch (IOException ex) {
                log("DiskUsage plugin error: " + ex.toString());
                log("DiskUsage plugin path:" + realPath);
            }
//           Properties userInfo = (Properties)info.get("user_info");
        //crushftp.handlers.Common.debug(0,userInfo.getProperty("user_name")+":"+info.getProperty("realPath"));
        // set "usedQuota" to number of used bytes (string value)
        } else if (action.equals("afterLogin")) {
            // Ensure that the right filter settings are set so .du files are invisible
            Properties serverSettings = (Properties) info.get("server_settings");
            String filnameFilters = serverSettings.getProperty("filename_filters_str");
            Set<String> filters = new TreeSet<String>();
            StringTokenizer lines = new StringTokenizer(filnameFilters, "\n;");
            while (lines.hasMoreTokens()) {
                String f = lines.nextToken().trim();
                if (f.length() != 0) {
                    filters.add(f);
                }
            }
            filters.add(":LS:.du"); // Listing starts with
            filters.add(":RS:.du"); // Remove starts with
            filters.add(":US:.du"); // Upload starts with
            filters.add(":DS:.du"); // Download starts with
            StringBuilder buf = new StringBuilder();
            for (String f : filters) {
                buf.append(f);
                buf.append(";\n");
            }
            serverSettings.put("filename_filters_str", buf.toString());
            debug("DiskUsage: Setting filename filters to " + buf.toString());
        }

//        if (!action.equals("") && !action.equals("log")) {
//            debug("Action is: " + action);
//            Properties settings = (Properties) info.get("server_settings");
//
//            debug("filters: " + settings.get("filename_filters_str").getClass());
//        }

        return null;
    }

    public void testSettings() {
//        log("testSettings called");
        String error = "OK";
        try {
        } catch (Exception e) {
            error = e.toString();
        }
        JOptionPane.showMessageDialog(null, error, "Alert", JOptionPane.ERROR_MESSAGE);
    }

    public String get(String key) {
        return settings.getProperty(key);
    }

    private void debug(String string) {
        if (settings.getProperty("debug").equalsIgnoreCase("true")) {
            crushftp.handlers.Common.debug(0, string);
        }
    }

    private void log(String string) {
        crushftp.handlers.Common.debug(0, string);
    }
}
